@@ -1,4 +1,4 @@
-import datetime
+import unicodedata
 
 
 def remove_tags_from_string(tags, text):
@@ -10,3 +10,7 @@ def replace_html_entities(replace_dict, text):
         text = text.replace(key, replace_dict[key])
         text = text.strip()
     return text
+
+
+def remove_emoji(text):
+    return unicodedata.normalize('NFKD', text).encode('ascii', 'ignore')
